'use client'

import Link from 'next/link'

import { useMutation, useQueryClient } from '@tanstack/react-query'
import { X } from 'lucide-react'

import { Button } from '@/components/ui/button'
import { Input } from '@/components/ui/input'
import useGetCheckoutData from '@/hooks/server/useGetCheckoutData'
import { convertToMoney } from '@/lib/utils'
import axiosClient from '@/services/axiosClient'
import { useCheckoutStore } from '@/store/checkout'

const PromoCodeOrGiftCart = () => {
  const queryClient = useQueryClient()
  const setCheckoutStore = useCheckoutStore((state) => state.setCheckoutStore)
  const promotionCodeValue = useCheckoutStore(
    (state) => state.promotionCodeValue
  )
  const { checkoutData, isFetching, handleFromDeleteCheckoutValidData } =
    useGetCheckoutData()
  const itemsCount = checkoutData?.products?.reduce(
    (acc, item) => acc + item.quantity,
    0
  )

  const deleteFromCartPopupMutation = useMutation({
    mutationFn: (id: number) => axiosClient.delete(`api/carts/${id}`),
    onSuccess: (_, variables) => {
      queryClient.invalidateQueries({ queryKey: ['cart'] })
      queryClient.invalidateQueries({ queryKey: ['checkout'] })
      handleFromDeleteCheckoutValidData(variables)
    },
    onError: (error) => {
      console.log(error)
    },
  })

  const handleApply = () => {
    setCheckoutStore('promotion_code', promotionCodeValue)
  }

  return (
    <div className='sticky top-28 flex w-72 flex-col gap-4 overflow-hidden rounded-lg p-4 md:relative md:top-auto md:w-full'>
      <div className='gradient' />
      <div className='custom-scrollbar max-h-[26rem] w-full divide-y overflow-y-auto'>
        {checkoutData?.products.map((item) => (
          <div
            key={item.id}
            className='relative flex items-center gap-4 py-2 text-muted-foreground'
          >
            <div className='flex flex-1 flex-col pe-5'>
              <Link
                href={`/product/${item?.slug}`}
                className='line-clamp-1 text-base transition-colors hover:text-primary'
              >
                {item.title}
              </Link>
              {item.variation?.title && (
                <div>Չափս: {item.variation?.title}</div>
              )}
              <div>
                {item.quantity} x {convertToMoney(item.discount_price)}
              </div>
            </div>
            <Button
              variant='ghost'
              size='iconSm'
              className='absolute right-0 top-0 rounded-full p-2'
              disabled={deleteFromCartPopupMutation.isPending}
              onClick={() => deleteFromCartPopupMutation.mutate(item.id)}
            >
              <X size={18} />
            </Button>
          </div>
        ))}
      </div>
      <div className='text-sm'>
        {itemsCount} {itemsCount === 1 ? 'Ապրանք' : 'Ապրանքներ'}
      </div>
      {!!checkoutData?.delivery && (
        <div className='clear-start flex justify-between gap-2 text-sm'>
          <div>Առաքում</div>
          <div>{convertToMoney(checkoutData?.delivery)}</div>
        </div>
      )}

      <Input
        id='promotion_code'
        value={promotionCodeValue}
        onChange={(e) => setCheckoutStore('promotionCodeValue', e.target.value)}
        placeholder='Պրոմո կոդ կամ նվեր քարտ'
        className='placeholder:text-sm'
        onKeyDown={(e) => {
          if (e.key === 'Enter') {
            handleApply()
          }
        }}
      />
      <Button
        variant='outlineSecondary'
        onClick={handleApply}
        disabled={isFetching}
      >
        Կիրառել
      </Button>
      <div className='flex flex-col gap-2'>
        {!!checkoutData?.promotion.value && (
          <div className='clear-start flex justify-between gap-2 text-sm'>
            <div>Պրոմո կոդ</div>
            <div>{checkoutData?.promotion.value}</div>
          </div>
        )}
        {!!checkoutData?.gift_card.amount && (
          <div className='clear-start flex justify-between gap-2 text-sm'>
            <div>Նվեր քարտ</div>
            <div>{convertToMoney(checkoutData?.gift_card.amount)}</div>
          </div>
        )}
        <div className='clear-start flex justify-between gap-2 pt-4 text-sm'>
          <div>Վերջնական արժեք</div>
          <div>{convertToMoney(checkoutData?.total)}</div>
        </div>
      </div>
    </div>
  )
}

export default PromoCodeOrGiftCart
