'use client'

import Link from 'next/link'

import { useQuery } from '@tanstack/react-query'

import Spinner from '@/components/ui/Spinner'
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from '@/components/ui/table'
import { convertToMoney } from '@/lib/utils'
import { getOrders } from '@/server/getOrders'

export default function Page() {
  const { data: ordersData, isPending } = useQuery({
    queryKey: ['orders'],
    queryFn: () => getOrders(),
  })

  return (
    <div className='w-full flex-1'>
      <Spinner isSpinning={isPending} />
      <h1 className='pb-6 text-2xl font-bold'>Պատվերներ</h1>
      <Table>
        <TableHeader>
          <TableRow className='bg-muted hover:bg-muted'>
            <TableHead className='w-[40px] font-bold'>ID</TableHead>
            <TableHead className='font-bold'>Կարգավիճակ</TableHead>
            <TableHead className='font-bold'>Ապրանքներ</TableHead>
            <TableHead className='font-bold'>Ամսաթիվ</TableHead>
            <TableHead className='text-end font-bold'>Ընդամենը</TableHead>
          </TableRow>
        </TableHeader>
        <TableBody>
          {ordersData && ordersData?.length > 0 ? (
            <>
              {ordersData?.map((item) => (
                <TableRow
                  key={item.id}
                  //  className='hover:bg-background'
                >
                  <TableCell>
                    <Link
                      href={`/orders/${item.id}`}
                      className='hover:underline'
                    >
                      {item.id}
                    </Link>
                  </TableCell>
                  <TableCell>{item.status}</TableCell>
                  <TableCell>
                    {item.products &&
                      item.products.length > 0 &&
                      item.products.map((product: any, index: number) => (
                        <Link
                          key={index}
                          href={`/product/${product.slug}`}
                          target='_blank'
                          className='hover:underline'
                        >
                          <div>{product.title}</div>
                        </Link>
                      ))}
                  </TableCell>
                  <TableCell className='whitespace-nowrap'>
                    {item.date}
                  </TableCell>
                  <TableCell className='text-end'>
                    {convertToMoney(item.total)}
                  </TableCell>
                </TableRow>
              ))}
            </>
          ) : (
            <TableRow>
              <TableCell colSpan={5}>
                <div className='flex h-12 flex-col items-center justify-center text-base text-muted-foreground'>
                  Ոչ մի պատվեր չի գտնվել
                </div>
              </TableCell>
            </TableRow>
          )}
        </TableBody>
      </Table>
    </div>
  )
}
