'use client'

import { useSearchParams } from 'next/navigation'
import { useEffect } from 'react'

import { useQuery } from '@tanstack/react-query'
import axios from 'axios'
import Cookies from 'js-cookie'
import { useRouter } from 'next-nprogress-bar'

import Spinner from '@/components/ui/Spinner'
import { getCart } from '@/server/getCart'
import { setNextCookies } from '@/utils/setNextCookies'

export default function EmailVerification() {
  const router = useRouter()
  const temporaryToken = Cookies.get('temporaryToken')
  const searchParams = useSearchParams()
  const hash = searchParams.get('hash') as string
  const id = searchParams.get('id') as string
  const { data: cartData } = useQuery({
    queryKey: ['cart'],
    queryFn: getCart,
  })

  if (!hash || !id) {
    router.push('/')
  }

  const handleEmailVerification = async () => {
    try {
      const res = await axios.get(
        `${process.env.NEXT_PUBLIC_API_URL}api/verify-email/${id}/${hash}`,
        {
          headers: {
            Authorization: `Bearer ${temporaryToken}`,
          },
        }
      )
      const token = res.data.token
      if (cartData && cartData?.products?.length > 0) {
        await axios.post(
          `${process.env.NEXT_PUBLIC_API_URL}api/carts`,
          {
            products: cartData.products?.map((item) => ({
              haysell_id: item.product.haysell_id,
              quantity: item.quantity,
              variation_id: item.variation?.id,
            })),
            is_cart: true,
          },
          {
            headers: {
              Authorization: `Bearer ${token}`,
            },
          }
        )
      }
      Cookies.set('siamoods_token', token)
      setNextCookies('siamoods_token', token)
      window.location.href = '/'
    } catch (error) {
      console.log(error)
    }
  }

  useEffect(() => {
    handleEmailVerification()
  }, [])

  return (
    <div>
      <div className='fixed inset-0 z-20 bg-white' />
      <Spinner isSpinning={true} />
      <h1 className='fixed left-1/2 top-1/2 z-40 -translate-x-1/2 -translate-y-1/2 pt-64 text-3xl text-muted-foreground'>
        Խնդրում ենք սպասել
      </h1>
    </div>
  )
}
