import type { Metadata } from 'next'
import { Inter as FontSans } from 'next/font/google'

import { GoogleOAuthProvider } from '@react-oauth/google'
import {
  HydrationBoundary,
  QueryClient,
  dehydrate,
} from '@tanstack/react-query'

import FacebookInit from '@/components/FacebookInit'
import Footer from '@/components/Footer'
import GenerateToken from '@/components/GenerateToken'
import LoadScripts from '@/components/LoadScripts'
import ProgressbarProvider from '@/components/ProgressbarProvider'
import ReactQueryClientProvider from '@/components/ReactQueryClientProvider'
import Header from '@/components/header/Header'
import { Toaster } from '@/components/ui/toaster'
import { cn } from '@/lib/utils'
import axiosServer from '@/services/axiosServer'
import { HomeData } from '@/types'

import './globals.css'
import './reset.css'

const fontSans = FontSans({
  subsets: ['latin'],
  variable: '--font-sans',
})

export const metadata: Metadata = {
  title: 'Արծաթյա զարդեր | Նվերներ | Օնլայն Խանութ | Երևան | SiaMoods',
  description: 'Արծաթյա զարդեր | Նվերներ | Օնլայն Խանութ | Երևան | SiaMoods',
  // icons: {
  //   icon: [
  //     {
  //       url: '/favicon.ico',
  //       type: 'image/x-icon',
  //     },
  //     {
  //       url: '/favicon-16x16.png',
  //       sizes: '16x16',
  //       type: 'image/png',
  //     },
  //     {
  //       url: '/favicon-32x32.png',
  //       sizes: '32x32',
  //       type: 'image/png',
  //     },
  //     {
  //       url: '/android-chrome-192x192.png',
  //       sizes: '192x192',
  //       type: 'image/png',
  //     },
  //   ],
  //   shortcut: [
  //     {
  //       url: '/favicon.ico',
  //       type: 'image/x-icon',
  //     },
  //   ],
  //   apple: [
  //     {
  //       url: '/apple-icon-57x57.png',
  //       sizes: '57x57',
  //       type: 'image/png',
  //     },
  //     {
  //       url: '/apple-icon-60x60.png',
  //       sizes: '60x60',
  //       type: 'image/png',
  //     },
  //   ],
  // },
}

export default async function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode
}>) {
  const queryClient = new QueryClient()
  await queryClient.prefetchQuery({
    queryKey: ['home'],
    queryFn: async (): Promise<HomeData | undefined> => {
      const res = await axiosServer('api/get-home')
      return res.data.data
    },
  })

  return (
    <html lang='en'>
      <body
        className={cn(
          'min-h-screen bg-background font-sans antialiased',
          fontSans.variable
        )}
      >
        <ReactQueryClientProvider>
          <HydrationBoundary state={dehydrate(queryClient)}>
            <ProgressbarProvider>
              <LoadScripts />

              <GoogleOAuthProvider
                clientId={process.env.NEXT_PUBLIC_GOOGLE_CLIENT_ID!}
              >
                <FacebookInit />
                <GenerateToken />
                <Header />
                {children}
                <Footer />
                <Toaster />
              </GoogleOAuthProvider>
            </ProgressbarProvider>
          </HydrationBoundary>
        </ReactQueryClientProvider>
      </body>
    </html>
  )
}
