'use client'

import { Button } from '@/components/ui/button'
import { getStoreData } from '@/server/getStore'
import { useQuery } from '@tanstack/react-query'
import FilterItem from './FilterItem'
import { useRouter } from 'next-nprogress-bar'
import FilterPrice from './FilterPrice'
import FilterPriceForSubStore from './FilterPriceForSubStore'

const Filter = ({
  isInSubStore,
  type,
  subType,
}: {
  isInSubStore?: boolean
  type?: string
  subType?: string
}) => {
  const router = useRouter()

  const { data: storeData } = useQuery({
    queryKey: ['store'],
    queryFn: getStoreData,
    staleTime: 1000 * 60 * 60,
  })

  if (!storeData) return null

  return (
    <div className='sticky top-28 w-64 flex-shrink-0 md:static md:w-full'>
      <div className='custom-scrollbar flex max-h-[calc(100dvh-9rem)] flex-col gap-4 overflow-y-auto rounded-lg border px-3 py-4'>
        <div className='flex items-center justify-between'>
          <div className='text-lg font-bold'>Ֆիլտրել</div>
          <Button
            variant='secondary'
            onClick={() => {
              // clear all filters
              router.push('/store')
            }}
          >
            Մաքրել
          </Button>
        </div>
        <div>
          <FilterItem
            name='balance'
            title='Առկայությունը'
            items={[
              {
                id: 1,
                name: 'Առկա է',
              },
            ]}
            type={type}
            subType={subType}
          />
          <FilterItem
            name='type'
            title='Տեսակը'
            items={storeData.types}
            type={type}
            subType={subType}
          />
          <FilterItem
            name='stone'
            title='Քարերը'
            items={storeData.stones}
            type={type}
            subType={subType}
          />
          <FilterItem
            name='filter'
            title='Հավաքածուն'
            items={storeData.collections}
            type={type}
            subType={subType}
          />
          {isInSubStore ? <FilterPriceForSubStore /> : <FilterPrice />}
        </div>
      </div>
    </div>
  )
}

export default Filter
