'use client'

import { useSearchParams } from 'next/navigation'
import { useEffect } from 'react'

import { AxiosError } from 'axios'
import { useRouter } from 'next-nprogress-bar'

import Spinner from '@/components/ui/Spinner'
import { useToast } from '@/components/ui/use-toast'
import axiosClient from '@/services/axiosClient'

export default function Unsubscribe() {
  const router = useRouter()
  const searchParams = useSearchParams()
  const email = searchParams.get('email') as string
  const { toast } = useToast()

  if (!email) {
    router.push('/')
  }

  const handleUnsubscribe = async () => {
    try {
      await axiosClient.post(`api/unsubscribe/${email}`)
      toast({
        title: 'Դուք հաջողությամբ ապաբաժանել եք բոլոր նորություններից',
      })
    } catch (error) {
      if (error instanceof AxiosError) {
        if (error?.response?.data.message) {
          toast({
            title: error.response.data.message,
            variant: 'destructive',
          })
        }
      }
    }
    router.push('/')
  }

  useEffect(() => {
    handleUnsubscribe()
  }, [])

  return (
    <div className='relative mx-auto my-8 flex h-80 max-w-lg items-center justify-center rounded-xl p-8 shadow-xl'>
      <div className='relative space-y-14 pb-14'>
        <h1 className='text-2xl font-bold text-primary'>
          Ապաբաժանորդագրություն
        </h1>
        <Spinner
          isSpinning={true}
          spinnerClassName='w-14 border-b-2'
          background={false}
          center={true}
        />
      </div>
    </div>
  )
}
