'use client'

import { cn } from '@/lib/utils'
import type { HeaderData } from '@/types'
import { ChevronDown, ChevronRight } from 'lucide-react'
import { useState } from 'react'
import NavItem from './NavItem'
import NavSubItem from './NavSubItem'

const Nav = ({
  className,
  headerData,
}: {
  className?: string
  headerData: HeaderData[]
}) => {
  const [activeItem, setActiveItem] = useState<number | null>(null)
  const [activeSubItem, setActiveSubItem] = useState<number | null>(null)
  let timeoutId: NodeJS.Timeout

  return (
    <ul className={cn('flex', className)}>
      {headerData.map((item, index) => (
        <li key={index}>
          <ul className='relative'>
            <NavItem
              href={item.href}
              onMouseEnter={() => {
                clearTimeout(timeoutId)
                setActiveItem(index)
                setActiveSubItem(null)
              }}
              onMouseLeave={() =>
                (timeoutId = setTimeout(() => setActiveItem(null), 100))
              }
              onClick={() => {
                if (item.href) {
                  setActiveItem(null)
                  setActiveSubItem(null)
                }
              }}
            >
              {item.name}
              {item.subItems && item.subItems.length > 0 && (
                <ChevronDown
                  size={18}
                  className='translate-x-0.5 translate-y-px opacity-80'
                />
              )}
            </NavItem>
            {activeItem === index &&
              item.subItems &&
              item.subItems.length > 0 && (
                <ul
                  className='absolute left-0 top-12 flex flex-col rounded-md bg-background p-2 shadow-md'
                  onMouseEnter={() => clearTimeout(timeoutId)}
                  onMouseLeave={() => {
                    timeoutId = setTimeout(() => setActiveItem(null), 100)
                  }}
                  onClick={() => {
                    setActiveItem(null)
                    setActiveSubItem(null)
                  }}
                >
                  {item.subItems.map((subItem, subIndex) => (
                    <li
                      key={subIndex}
                      onMouseEnter={() => {
                        setActiveSubItem(subIndex)
                      }}
                      onClick={() => {
                        setActiveItem(null)
                        setActiveSubItem(null)
                      }}
                    >
                      <ul>
                        <NavSubItem
                          href={subItem.href}
                          // className={
                          //   pathname === subItem.href
                          //     ? 'text-primary hover:text-primary'
                          //     : ''
                          // }
                        >
                          {subItem.name}
                          {subItem.subItems && subItem.subItems.length > 0 && (
                            <ChevronRight size={18} className='opacity-80' />
                          )}
                        </NavSubItem>
                      </ul>
                      {activeSubItem === subIndex &&
                        subItem.subItems &&
                        subItem.subItems.length > 0 && (
                          <ul
                            className='absolute right-2 top-0 flex translate-x-[calc(100%+0.5rem)] flex-col rounded-md bg-background p-2 shadow-md'
                            onMouseEnter={() => clearTimeout(timeoutId)}
                          >
                            {subItem.subItems.map((subSubItem, subSubIndex) => (
                              <NavSubItem
                                key={subSubIndex}
                                href={subSubItem.href}
                                // className={
                                //   pathname === subSubItem.href
                                //     ? 'text-primary hover:text-primary'
                                //     : ''
                                // }
                              >
                                {subSubItem.name}
                              </NavSubItem>
                            ))}
                          </ul>
                        )}
                    </li>
                  ))}
                </ul>
              )}
          </ul>
        </li>
      ))}
    </ul>
  )
}

export default Nav
