/* eslint-disable */
const { createServer } = require('http')
const { parse } = require('url')
const next = require('next')
const createSitemapTask = require('./cron/sitemap')

const dev = process.env.NODE_ENV !== 'production'
const hostname = 'localhost'
const port = process.env.port || 3000
const app = next({ dev, hostname, port })
const handle = app.getRequestHandler()

app.prepare().then(() => {
  // Start the sitemap update task
  const sitemapTask = createSitemapTask('0 0 * * *')

  createServer(async (req, res) => {
    try {
      const parsedUrl = parse(req.url, true)
      const { pathname, query } = parsedUrl

      if (pathname === '/a') {
        await app.render(req, res, '/a', query)
      } else if (pathname === '/b') {
        await app.render(req, res, '/b', query)
      } else {
        await handle(req, res, parsedUrl)
      }
    } catch (err) {
      console.error('Error occurred handling', req.url, err)
      res.statusCode = 500
      res.end('internal server error')
    }
  })
    .once('error', (err) => {
      console.error(err)
      process.exit(1)
    })
    .listen(port, () => {
      console.log(`> Ready on http://${hostname}:${port}`)
    })

  // Handle process termination
  process.on('SIGTERM', () => {
    console.log('SIGTERM received - cleaning up...')
    sitemapTask.stop()
    process.exit(0)
  })

  process.on('SIGINT', () => {
    console.log('SIGINT received - cleaning up...')
    sitemapTask.stop()
    process.exit(0)
  })
})
