import { create } from 'zustand'

interface CheckoutState {
  deliveryTypeId: string
  state_1: string
  state_2: string
  another_shipping_address: string
  promotionCodeValue: string
  promotion_code: string
  email: string
  gift_card: string
  promotion: string
  navigatedFromCheckout: string
}

interface OtherCheckoutState {}

interface CheckoutActions {
  setCheckoutStore: (key: keyof CheckoutState, value: string) => void
  restoreCheckoutStore: () => void
}

const DEFAULT_VALUES: Omit<CheckoutState, 'navigatedFromCheckout'> = {
  deliveryTypeId: '0',
  state_1: 'ER',
  state_2: '',
  another_shipping_address: '0',
  promotionCodeValue: '',
  promotion_code: '',
  email: '',
  gift_card: '',
  promotion: '',
}

export const useCheckoutStore = create<
  CheckoutState & OtherCheckoutState & CheckoutActions
>()((set) => ({
  ...DEFAULT_VALUES,
  navigatedFromCheckout: '0',
  setCheckoutStore: (key, value) => set({ [key]: value }),
  restoreCheckoutStore: () =>
    set((state) => ({
      ...DEFAULT_VALUES,
      navigatedFromCheckout: state.navigatedFromCheckout,
    })),
}))
